# NOTES

- Sripts under `experiments/legacy` are out of maintaince that it cannot work with the latest implementation.
- For the current codebase, please refer to `experiments/README.md`.

However, the legacy code might work with `620645967a14d6a7b077cedd9c2c03ed74af50d9` which is used in the ASPLOS'23 [artifact](http://nnsmith-asplos.rtfd.io/).
For more information of using legacy code to render outputs in our artifact, please refer to bash scripts in the artifact [repository](https://github.com/ganler/nnsmith-asplos-artifact).
